@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import logging
-import sys
+import pickle
 from typing import TYPE_CHECKING
 
 from flake8_type_checking.checker import TypingOnlyImportsChecker
@@ -15,12 +15,7 @@ if TYPE_CHECKING:
 
     from flake8_type_checking.types import Flake8Generator
 
-
-if sys.version_info >= (3, 8):
-    from importlib.metadata import version
-else:
-    # noinspection PyUnresolvedReferences
-    from importlib_metadata import version
+from importlib.metadata import version
 
 logger = logging.getLogger('flake8.type_checking')
 
@@ -45,8 +40,10 @@ class Plugin:
             comma_separated_list=True,
             parse_from_config=True,
             default=[],
-            help='Skip TC001 and TC002 checks for specified modules or libraries.',
+            help='Skip TC001, TC002, and TC003 checks for specified modules or libraries.',
         )
+
+        # Third-party library options
         option_manager.add_option(
             '--type-checking-pydantic-enabled',
             action='store_true',
@@ -75,10 +72,23 @@ class Plugin:
             default=False,
             help='Prevent flagging of annotations for any function.',
         )
+        option_manager.add_option(
+            '--type-checking-cattrs-enabled',
+            action='store_true',
+            parse_from_config=True,
+            default=False,
+            help='Prevent flagging of annotations on attrs class definitions.',
+        )
 
     def run(self) -> Flake8Generator:
-        """Run flake8 plugin and return any relevant errors."""
-        visitor = TypingOnlyImportsChecker(self._tree, self.options)
+        """
+        Run flake8 plugin and return any relevant errors.
+
+        We use pickle.loads/dumps here as a more performant alternative to deepcopy,
+        since we mutate the tree we receive and not copying it like this will lead
+        to errors in consequent plugins.
+        """
+        visitor = TypingOnlyImportsChecker(pickle.loads(pickle.dumps(self._tree, -1)), self.options)
         for e in visitor.errors:
             if self.should_warn(e[2].split(':')[0]):
                 yield e
